==> openapi-generator-7.1.0-sources.jar: org/openapitools/codegen/templating/mustache/OptionalParameterLambda.java <==
/*
 * Copyright 2018 OpenAPI-Generator Contributors (https://openapi-generator.tech)
 * Copyright 2018 SmartBear Software
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.openapitools.codegen.templating.mustache;

import com.samskivert.mustache.Mustache;
import com.samskivert.mustache.Template;
import org.openapitools.codegen.CodegenConfig;
import org.openapitools.codegen.languages.AbstractCSharpCodegen;

import java.io.IOException;
import java.io.Writer;

/**
 * Appends trailing ? to a text fragment if not already present
 *
 * Register:
 * <pre>
 * additionalProperties.put("optional", new OptionalParameterLambda());
 * </pre>
 *
 * Use:
 * <pre>
 * {{#lambda.optional}}{{name}}{{/lambda.optional}}
 * </pre>
 */
public class OptionalParameterLambda implements Mustache.Lambda {
    private CodegenConfig generator = null;

    public OptionalParameterLambda() {}

    public OptionalParameterLambda generator(final CodegenConfig generator) {
        this.generator = generator;
        return this;
    }

    @Override
    public void execute(Template.Fragment fragment, Writer writer) throws IOException {
        String text = fragment.execute();

        if (this.generator instanceof AbstractCSharpCodegen){
            AbstractCSharpCodegen csharpGenerator = (AbstractCSharpCodegen) this.generator;
            if (csharpGenerator.getNullableReferencesTypes()){
                text = text.endsWith("?")
                    ? text
                    : text + "?";
            }
        }

        writer.write(text);
    }
}

==> openapi-generator-7.16.0-sources.jar: org/openapitools/codegen/templating/mustache/OptionalParameterLambda.java <==
/*
 * Copyright 2018 OpenAPI-Generator Contributors (https://openapi-generator.tech)
 * Copyright 2018 SmartBear Software
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.openapitools.codegen.templating.mustache;

import com.samskivert.mustache.Mustache;
import com.samskivert.mustache.Template;
import org.openapitools.codegen.CodegenConfig;
import org.openapitools.codegen.languages.AbstractCSharpCodegen;

import java.io.IOException;
import java.io.Writer;

/**
 * Appends trailing ? to a text fragment if not already present
 * <p>
 * Register:
 * <pre>
 * additionalProperties.put("optional", new OptionalParameterLambda());
 * </pre>
 * <p>
 * Use:
 * <pre>
 * {{#lambda.optional}}{{name}}{{/lambda.optional}}
 * </pre>
 */
public class OptionalParameterLambda implements Mustache.Lambda {
    private CodegenConfig generator = null;

    public OptionalParameterLambda() {
    }

    public OptionalParameterLambda generator(final CodegenConfig generator) {
        this.generator = generator;
        return this;
    }

    @Override
    public void execute(Template.Fragment fragment, Writer writer) throws IOException {
        String text = fragment.execute();

        if (this.generator instanceof AbstractCSharpCodegen) {
            AbstractCSharpCodegen csharpGenerator = (AbstractCSharpCodegen) this.generator;
            if (csharpGenerator.getNullableReferencesTypes()) {
                text = text.endsWith("?")
                        ? text
                        : text + "?";
            }
        }

        writer.write(text);
    }
}
